powered by
Checks if an object is a Camera Trap Data Package object with the required properties.
check_camtrapdp(x)
x invisibly or an error.
x
Camera Trap Data Package object, as returned by read_camtrapdp().
read_camtrapdp()
x <- example_dataset() check_camtrapdp(x) # Invisible return of x if valid
Run the code above in your browser using DataLab