Learn R Programming

camtrapdp (version 0.4.0)

individuals: Get individuals

Description

Gets the (unique) individuals from the observations of a Camera Trap Data Package object.

Usage

individuals(x)

Value

A tibble::tibble() data frame with the individuals that have an individualID, containing the following columns:

  • individualID

  • scientificName

  • lifeStage

  • sex

Arguments

x

Camera Trap Data Package object, as returned by read_camtrapdp().

See Also

Other accessor functions: contributors(), deployments(), events(), locations(), media(), observations(), taxa()

Examples

Run this code
x <- example_dataset()
individuals(x)

Run the code above in your browser using DataLab