powered by
Gets the (unique) individuals from the observations of a Camera Trap Data Package object.
individuals(x)
A tibble::tibble() data frame with the individuals that have an individualID, containing the following columns:
tibble::tibble()
individualID
scientificName
lifeStage
sex
Camera Trap Data Package object, as returned by read_camtrapdp().
read_camtrapdp()
Other accessor functions: contributors(), deployments(), events(), locations(), media(), observations(), taxa()
contributors()
deployments()
events()
locations()
media()
observations()
taxa()
x <- example_dataset() individuals(x)
Run the code above in your browser using DataLab