Gets the (unique) scientific names and associated taxonomic information from
the observations of a Camera Trap Data Package object.
Duplicate taxa (i.e. with the same scientificName) are removed, retaining
the taxon with (first) a taxonID and (second) the most taxonomic
information.
Usage
taxa(x)
Value
A tibble::tibble() data frame with the taxonomic information,
containing at least a scientificName column.
Arguments
x
Camera Trap Data Package object, as returned by read_camtrapdp().
See Also
Other accessor functions:
contributors(),
deployments(),
events(),
individuals(),
locations(),
media(),
observations()